@@ -67,7 +67,7 @@ class RaceHandler:
         """
         msg_type = data.get('type')
 
-        self.logger.info('[%(race)s] Recieved %(msg_type)s' % {
+        self.logger.info('[%(race)s] Received %(msg_type)s' % {
             'race': self.data.get('name'),
             'msg_type': msg_type,
         })
@@ -119,7 +119,11 @@ class RaceHandler:
                     'race': self.data.get('name'),
                     'word': words[0],
                 })
-                await getattr(self, method)(args, message)
+                try:
+                    await getattr(self, method)(args, message)
+                except Exception as e:
+                    self.logger.error('Command raised exception.', exc_info=True)
+
 
     async def race_data(self, data):
         """
